@@ -1,5 +1,6 @@
 import logging
 import os
+import warnings
 from io import BytesIO
 
 from django.core.files.base import ContentFile
@@ -11,12 +12,21 @@ from django.db.models.fields.files import (
     ImageFileDescriptor,
 )
 from PIL import Image, ImageFile, ImageOps
+from PIL.Image import Resampling
 
 from .validators import MinSizeValidator
 
 logger = logging.getLogger()
 
 
+warnings.warn(
+    "The django-stdimage is deprecated in favor of django-pictures.\n"
+    "Migration instructions are available in the README:\n"
+    "https://github.com/codingjoe/django-stdimage#migration-instructions",
+    DeprecationWarning,
+)
+
+
 class StdImageFileDescriptor(ImageFileDescriptor):
     """The variation property of the field is accessible in instance cases."""
 
@@ -144,6 +154,25 @@ class StdImageFieldFile(ImageFieldFile):
             variation_name = self.get_variation_name(self.name, variation)
             self.storage.delete(variation_name)
 
+    def __getstate__(self):
+        state = super().__getstate__()
+        state["variations"] = {}
+        for variation_name in self.field.variations:
+            variation = getattr(self, variation_name)
+            variation_state = variation.__getstate__()
+            state["variations"][variation_name] = variation_state
+        return state
+
+    def __setstate__(self, state):
+        variations = state["variations"]
+        state.pop("variations")
+        super().__setstate__(state)
+        for key, value in variations.items():
+            cls = ImageFieldFile
+            field = cls.__new__(cls)
+            setattr(self, key, field)
+            getattr(self, key).__setstate__(value)
+
 
 class StdImageField(ImageField):
     """
@@ -167,7 +196,7 @@ class StdImageField(ImageField):
         "width": None,
         "height": None,
         "crop": False,
-        "resample": Image.ANTIALIAS,
+        "resample": Resampling.LANCZOS,
     }
 
     def __init__(
@@ -287,6 +316,19 @@ class StdImageField(ImageField):
                 file.delete(save=False)
         super().save_form_data(instance, data)
 
+    def deconstruct(self):
+        name, path, args, kwargs = super().deconstruct()
+        return (
+            name,
+            path,
+            args,
+            {
+                **kwargs,
+                "variations": self._variations,
+                "force_min_size": self.force_min_size,
+            },
+        )
+
 
 class JPEGFieldFile(StdImageFieldFile):
     @classmethod
@@ -304,16 +346,13 @@ class JPEGFieldFile(StdImageFieldFile):
 
         resample = variation["resample"]
 
-        if variation["width"] is None:
-            variation["width"] = image.size[0]
-
-        if variation["height"] is None:
-            variation["height"] = image.size[1]
+        width = image.size[0] if variation["width"] is None else variation["width"]
+        height = image.size[1] if variation["height"] is None else variation["height"]
 
         factor = 1
         while (
-            image.size[0] / factor > 2 * variation["width"]
-            and image.size[1] * 2 / factor > 2 * variation["height"]
+            image.size[0] / factor > 2 * width
+            and image.size[1] * 2 / factor > 2 * height
         ):
             factor *= 2
         if factor > 1:
@@ -322,7 +361,7 @@ class JPEGFieldFile(StdImageFieldFile):
                 resample=resample,
             )
 
-        size = variation["width"], variation["height"]
+        size = width, height
         size = tuple(int(i) if i is not None else i for i in size)
 
         # http://stackoverflow.com/a/21669827
